###
A Mixin to enhance items enhanced with the 'IsItem' Mixin with selection capability.

When a click event is received the current item will be stored in the parent view 'selected' property,
An extra 'active' css class will be assigned to the Item (this) if this is a selected item.
###
Bootstrap.ItemSelection = Ember.Mixin.create(
    classNameBindings: ["isActive:active"]

    ###
    Determine whether the current item is selected,
    if true the 'active' css class will be associated with the this DOM's element.

    This is a calculated property and will be retriggered if the 'value' property of the item has changed or the 'selected' property
    in the parent ItemsView.
    ###
    isActive: (->
        #TODO: Ensure parentView is inherited from ItemsView
        itemsView = @get('parentView')
        if not itemsView?
            return
        selected = itemsView.get 'selected'
        value = @get 'value'
        selected is value
    ).property('value', 'parentView.selected').cacheable()

    ###
    Handle selection by click event.

    The identifier of the selection is based on the 'content' property of this item.
    ###
    click: (event) ->
        #event.stopPropagation()
        event.preventDefault()

        #TODO: Ensure parentView is inherited from ItemsView
        itemsView = @get('parentView')
        if not itemsView?
            return

        content = @get('content')
        #TODO: Ensure its an Ember object
        if typeof(content) is 'object'
            return if content.get('disabled')

        #Currently multi selection is not supported
        itemsView.set('selected', @get('value'))
)